@@ -1,22 +1,22 @@
-# Reader for py4DSTEM v0.6 files
+# Reader for py4DSTEM v0.12 files
 
 import h5py
 import numpy as np
-from os.path import splitext
+from os.path import splitext, exists
 from .read_utils import is_py4DSTEM_file, get_py4DSTEM_topgroups, get_py4DSTEM_version, version_is_geq
-from .read_utils_v0_6 import get_py4DSTEM_dataobject_info
-from ...datastructure import DataCube, DiffractionSlice, RealSlice
-from ...datastructure import PointList, PointListArray
-from ....process.utils import tqdmnd
+from .read_utils_v0_12 import get_py4DSTEM_dataobject_info
+from ...datastructure import DataCube
+from ...datastructure import DiffractionSlice
+from ...datastructure import RealSlice
+from ...datastructure import PointList
+from ...datastructure import PointListArray
+from .... import tqdmnd
 
-def read_v0_6(fp, **kwargs):
+def read_v0_12(fp, **kwargs):
     """
-    File reader for files written by py4DSTEM v0.6.  Precise behavior is detemined by which
+    File reader for files written by py4DSTEM v0.12.  Precise behavior is detemined by which
     arguments are passed -- see below.
 
-    ***NOTE: this function has not yet been tested on all legacy py4DSTEM formats. Please report
-    any problems by filing an issue on our github!
-
     Accepts:
         filepath    str or Path     When passed a filepath only, this function checks if the path
                                     points to a valid py4DSTEM file, then prints its contents to screen.
@@ -36,7 +36,7 @@ def read_v0_6(fp, **kwargs):
                                     called splitext(fp)[0]+'.log'.
         mem         str             Only used if a single DataCube is loaded. In this case, mem
                                     specifies how the data should be stored; must be "RAM"
-                                    or "MEMMAP". See docstring for py4DSTEM.file.io.read. Default
+                                    or "MEMMAP" or "DASK". See docstring for py4DSTEM.file.io.read. Default
                                     is "RAM".
         binfactor   int             Only used if a single DataCube is loaded. In this case,
                                     a binfactor of > 1 causes the data to be binned by this amount
@@ -53,6 +53,7 @@ def read_v0_6(fp, **kwargs):
                                     will return a length two tuple, the first element being a list of 3
                                     DataObject instances and the second a MetaData instance.
     """
+    assert(exists(fp)), "Error: specified filepath does not exist"
     assert(is_py4DSTEM_file(fp)), "Error: {} isn't recognized as a py4DSTEM file.".format(fp)
 
     # For HDF5 files containing multiple valid EMD type 2 files, disambiguate desired data
@@ -72,79 +73,71 @@ def read_v0_6(fp, **kwargs):
             return None,None
 
     version = get_py4DSTEM_version(fp, tg)
-    assert(version == (0,6,0)), "File must be v0.6.0."
+    assert(version_is_geq(version,(0,12,0))), "File must be v0.12+"
     _data_id = 'data_id' in kwargs.keys()  # Flag indicating if data was requested
 
-    # Validate inputs
-    if _data_id:
+    # If metadata is requested
+    if 'metadata' in kwargs.keys():
+        if kwargs['metadata']:
+            return metadata_from_h5(fp, tg)
+
+    # If data is requested
+    elif 'data_id' in kwargs.keys():
         data_id = kwargs['data_id']
-        assert(isinstance(data_id,(int,str,list,tuple))), "Error: data must be specified with strings or integers only."
-        if not isinstance(data_id,(int,str)):
-            assert(all([isinstance(d,(int,str)) for d in data_id])), "Error: data must be specified with strings or integers only."
+        assert(isinstance(data_id,(int,np.int_,str,list,tuple))), "Error: data must be specified with strings or integers only."
+        if not isinstance(data_id,(int,np.int_,str)):
+            assert(all([isinstance(d,(int,np.int_,str)) for d in data_id])), "Error: data must be specified with strings or integers only."
 
-    # Parse optional arguments
-    if 'mem' in kwargs.keys():
-        mem = kwargs['mem']
-        assert(mem in ('RAM','MEMMAP'))
-    else:
-        mem='RAM'
-    if 'binfactor' in kwargs.keys():
-        binfactor = kwargs['binfactor']
-        assert(isinstance(binfactor,int))
-    else:
-        binfactor=1
-    if 'dtype' in kwargs.keys():
-        bindtype = kwargs['dtype']
-        assert(isinstance(bindtype,type))
-    else:
-        bindtype = None
+        # Parse optional arguments
+        if 'mem' in kwargs.keys():
+            mem = kwargs['mem']
+            assert(mem in ('RAM','MEMMAP', 'DASK'))
+        else:
+            mem='RAM'
+        if 'binfactor' in kwargs.keys():
+            binfactor = kwargs['binfactor']
+            assert(isinstance(binfactor,(int,np.int_)))
+        else:
+            binfactor=1
+        if 'dtype' in kwargs.keys():
+            bindtype = kwargs['dtype']
+            assert(isinstance(bindtype,type))
+        else:
+            bindtype = None
 
-    # Perform requested operations
-    if not _data_id:
-        print_py4DSTEM_file(fp,tg)
-        return
-    else:
         return get_data(fp,tg,data_id,mem,binfactor,bindtype)
 
-
-############ Helper functions ############
-
-def print_py4DSTEM_file(fp,tg):
-    """ Accepts a fp to a valid py4DSTEM file and prints to screen the file contents.
-    """
-    info = get_py4DSTEM_dataobject_info(fp,tg)
-
-    version = get_py4DSTEM_version(fp, tg)
-    print(f"py4DSTEM file version {version[0]}.{version[1]}.{version[2]}")
-
-    print("{:10}{:18}{:24}{:54}".format('Index', 'Type', 'Shape', 'Name'))
-    print("{:10}{:18}{:24}{:54}".format('-----', '----', '-----', '----'))
-    for el in info:
-        print("  {:8}{:18}{:24}{:54}".format(str(el['index']),str(el['type']),str(el['shape']),str(el['name'])))
-
-    return
-
-def get_data(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
-    """ Accepts a fp to a valid py4DSTEM file and an int/str/list specifying data, and returns the data.
-    """
-    if isinstance(data_id,int):
-        return get_data_from_int(fp,tg,data_id,mem=mem,binfactor=binfactor,bindtype=bindtype)
-    elif isinstance(data_id,str):
-        return get_data_from_str(fp,tg,data_id,mem=mem,binfactor=binfactor,bindtype=bindtype)
+    # If no data is requested
     else:
-        return get_data_from_list(fp,tg,data_id)
+        print_py4DSTEM_file(fp,tg)
+        return
 
-def get_data_from_int(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
-    """ Accepts a fp to a valid py4DSTEM file and an integer specifying data, and returns the data.
+
+###### Get data ######
+
+def get_data(filepath,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
+    """ Accepts a filepath to a valid py4DSTEM file and an int/str/list specifying data, and returns the data.
     """
-    assert(isinstance(data_id,int))
-    with h5py.File(fp,'r') as f:
+    if isinstance(data_id,(int,np.int_)):
+        return get_data_from_int(filepath,tg,data_id,mem=mem,binfactor=binfactor,bindtype=bindtype)
+    elif isinstance(data_id,str):
+        return get_data_from_str(filepath,tg,data_id,mem=mem,binfactor=binfactor,bindtype=bindtype)
+    else:
+        return get_data_from_list(filepath,tg,data_id)
+
+def get_data_from_int(filepath,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
+    """ Accepts a filepath to a valid py4DSTEM file and an integer specifying data, and returns the data.
+    """
+    assert(isinstance(data_id,(int,np.int_)))
+    with h5py.File(filepath,'r') as f:
         grp_dc = f[tg+'/data/datacubes/']
+        grp_cdc = f[tg+'/data/counted_datacubes/']
         grp_ds = f[tg+'/data/diffractionslices/']
         grp_rs = f[tg+'/data/realslices/']
         grp_pl = f[tg+'/data/pointlists/']
         grp_pla = f[tg+'/data/pointlistarrays/']
-        grps = [grp_dc,grp_ds,grp_rs,grp_pl,grp_pla]
+        grp_coords = f[tg+'/data/coordinates/']
+        grps = [grp_dc,grp_cdc,grp_ds,grp_rs,grp_pl,grp_pla,grp_coords]
 
         Ns = np.cumsum([len(grp.keys()) for grp in grps])
         i = np.nonzero(data_id<Ns)[0][0]
@@ -159,30 +152,40 @@ def get_data_from_int(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
             data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
     if mem == "MEMMAP":
-        f = h5py.File(fp,'r')
+        f = h5py.File(filepath,'r')
+        grp_data = f[group_name]
+        data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
+    # ADDING STUFF IN HERE,
+    # I need to change datacube and counted datacube 
+    elif mem == "DASK":
+        f = h5py.File(filepath, 'r')
         grp_data = f[group_name]
         data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
     return data
 
-def get_data_from_str(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
-    """ Accepts a fp to a valid py4DSTEM file and a string specifying data, and returns the data.
+def get_data_from_str(filepath,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
+    """ Accepts a filepath to a valid py4DSTEM file and a string specifying data, and returns the data.
     """
     assert(isinstance(data_id,str))
-    with h5py.File(fp,'r') as f:
+    with h5py.File(filepath,'r') as f:
         grp_dc = f[tg+'/data/datacubes/']
+        grp_cdc = f[tg+'/data/counted_datacubes/']
         grp_ds = f[tg+'/data/diffractionslices/']
         grp_rs = f[tg+'/data/realslices/']
         grp_pl = f[tg+'/data/pointlists/']
         grp_pla = f[tg+'/data/pointlistarrays/']
-        grps = [grp_dc,grp_ds,grp_rs,grp_pl,grp_pla]
+        grp_coords = f[tg+'/data/coordinates/']
+        grps = [grp_dc,grp_cdc,grp_ds,grp_rs,grp_pl,grp_pla,grp_coords]
 
         l_dc = list(grp_dc.keys())
+        l_cdc = list(grp_cdc.keys())
         l_ds = list(grp_ds.keys())
         l_rs = list(grp_rs.keys())
         l_pl = list(grp_pl.keys())
         l_pla = list(grp_pla.keys())
-        names = l_dc+l_ds+l_rs+l_pl+l_pla
+        l_coords = list(grp_coords.keys())
+        names = l_dc+l_cdc+l_ds+l_rs+l_pl+l_pla+l_coords
 
         inds = [i for i,name in enumerate(names) if name==data_id]
         assert(len(inds)!=0), "Error: no data named {} found.".format(data_id)
@@ -192,33 +195,34 @@ def get_data_from_str(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
         Ns = np.cumsum([len(grp.keys()) for grp in grps])
         i_grp = np.nonzero(ind<Ns)[0][0]
         grp = grps[i_grp]
-
         group_name = grp.name+'/'+data_id
 
         if mem == "RAM":
             grp_data = f[group_name]
             data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
-    # if using MEMMAP, file cannot be accessed from the context manager
-    # or else it will be closed before the data is accessed
     if mem == "MEMMAP":
-        f = h5py.File(fp,'r')
+        f = h5py.File(filepath,'r')
+        grp_data = f[group_name]
+        data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
+    elif mem == 'DASK':
+        f = h5py.File(filepath,'r')
         grp_data = f[group_name]
         data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
     return data
 
-def get_data_from_list(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
-    """ Accepts a fp to a valid py4DSTEM file and a list or tuple specifying data, and returns the data.
+def get_data_from_list(filepath,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
+    """ Accepts a filepath to a valid py4DSTEM file and a list or tuple specifying data, and returns the data.
     """
     assert(isinstance(data_id,(list,tuple)))
-    assert(all([isinstance(d,(int,str)) for d in data_id]))
+    assert(all([isinstance(d,(int,np.int_,str)) for d in data_id]))
     data = []
     for el in data_id:
-        if isinstance(el,int):
-            data.append(get_data_from_int(fp,tg,data_id=el,mem=mem,binfactor=binfactor,bindtype=bindtype))
+        if isinstance(el,(int,np.int_)):
+            data.append(get_data_from_int(filepath,tg,data_id=el,mem=mem,binfactor=binfactor,bindtype=bindtype))
         elif isinstance(el,str):
-            data.append(get_data_from_str(fp,tg,data_id=el,mem=mem,binfactor=binfactor,bindtype=bindtype))
+            data.append(get_data_from_str(filepath,tg,data_id=el,mem=mem,binfactor=binfactor,bindtype=bindtype))
         else:
             raise Exception("Data must be specified with strings or integers only.")
     return data
@@ -231,7 +235,8 @@ def get_data_from_grp(g,mem='RAM',binfactor=1,bindtype=None):
     if dtype == 'datacubes':
         return get_datacube_from_grp(g,mem,binfactor,bindtype)
     elif dtype == 'counted_datacubes':
-        return get_counted_datacube_from_grp(g)
+        raise NotImplementedError("CountedDataCube objects are not available in py4DSTEM v0.13")
+        # return get_counted_datacube_from_grp(g)
     elif dtype == 'diffractionslices':
         return get_diffractionslice_from_grp(g)
     elif dtype == 'realslices':
@@ -240,28 +245,50 @@ def get_data_from_grp(g,mem='RAM',binfactor=1,bindtype=None):
         return get_pointlist_from_grp(g)
     elif dtype == 'pointlistarrays':
         return get_pointlistarray_from_grp(g)
+    elif dtype == 'coordinates':
+        raise NotImplementedError("Conversion from legacy Coordinates object to v0.13 Calibration is not available...")
+        # return get_coordinates_from_grp(g)
     else:
         raise Exception('Unrecognized data object type {}'.format(dtype))
 
+
+# Print to screen
+
+def print_py4DSTEM_file(filepath,tg):
+    """ Accepts a filepath to a valid py4DSTEM file and prints to screen the file contents.
+    """
+    info = get_py4DSTEM_dataobject_info(filepath,tg)
+
+    version = get_py4DSTEM_version(filepath, tg)
+    print(f"py4DSTEM file version {version[0]}.{version[1]}.{version[2]}")
+
+    print("{:10}{:18}{:24}{:54}".format('Index', 'Type', 'Shape', 'Name'))
+    print("{:10}{:18}{:24}{:54}".format('-----', '----', '-----', '----'))
+    for el in info:
+        print("  {:8}{:18}{:24}{:54}".format(str(el['index']),str(el['type']),str(el['shape']),str(el['name'])))
+    return
+
+
+#####################################################
+# READERS SCRAPED FROM DATASTRUCTURE FILES IN v0.12 #
+#####################################################
+
 def get_datacube_from_grp(g,mem='RAM',binfactor=1,bindtype=None):
     """ Accepts an h5py Group corresponding to a single datacube in an open, correctly formatted H5 file,
         and returns a DataCube.
     """
+    # TODO: add binning
     assert binfactor == 1, "Bin on load is currently unsupported for EMD files."
 
     if (mem, binfactor) == ("RAM", 1):
+        stack_pointer = g['data']
         data = np.array(g['data'])
     elif (mem, binfactor) == ("MEMMAP", 1):
         data = g['data']
-    
+        stack_pointer = None
     name = g.name.split('/')[-1]
     return DataCube(data=data,name=name)
 
-def get_counted_datacube_from_grp(g):
-    """ Accepts an h5py Group corresponding to a counted datacube in an open, correctly formatted H5 file,
-        and returns a CountedDataCube.
-    """
-    return #TODO
 
 def get_diffractionslice_from_grp(g):
     """ Accepts an h5py Group corresponding to a diffractionslice in an open, correctly formatted H5 file,
@@ -271,14 +298,15 @@ def get_diffractionslice_from_grp(g):
     name = g.name.split('/')[-1]
     Q_Nx,Q_Ny = data.shape[:2]
     if len(data.shape)==2:
-        return DiffractionSlice(data=data,Q_Nx=Q_Nx,Q_Ny=Q_Ny,name=name)
+        return DiffractionSlice(data=data,name=name)
     else:
         lbls = g['dim3']
         if('S' in lbls.dtype.str): # Checks if dim3 is composed of fixed width C strings
             with lbls.astype('S64'):
                 lbls = lbls[:]
             lbls = [lbl.decode('UTF-8') for lbl in lbls]
-        return DiffractionSlice(data=data,Q_Nx=Q_Nx,Q_Ny=Q_Ny,name=name,slicelabels=lbls)
+        return DiffractionSlice(data=data,name=name,slicelabels=lbls)
+
 
 def get_realslice_from_grp(g):
     """ Accepts an h5py Group corresponding to a realslice in an open, correctly formatted H5 file,
@@ -288,14 +316,14 @@ def get_realslice_from_grp(g):
     name = g.name.split('/')[-1]
     R_Nx,R_Ny = data.shape[:2]
     if len(data.shape)==2:
-        return RealSlice(data=data,R_Nx=R_Nx,R_Ny=R_Ny,name=name)
+        return RealSlice(data=data,name=name)
     else:
         lbls = g['dim3']
         if('S' in lbls.dtype.str): # Checks if dim3 is composed of fixed width C strings
             with lbls.astype('S64'):
                 lbls = lbls[:]
             lbls = [lbl.decode('UTF-8') for lbl in lbls]
-        return RealSlice(data=data,R_Nx=R_Nx,R_Ny=R_Ny,name=name,slicelabels=lbls)
+        return RealSlice(data=data,name=name,slicelabels=lbls)
 
 def get_pointlist_from_grp(g):
     """ Accepts an h5py Group corresponding to a pointlist in an open, correctly formatted H5 file,
@@ -322,24 +350,13 @@ def get_pointlistarray_from_grp(g):
         and returns a PointListArray.
     """
     name = g.name.split('/')[-1]
-    l = list(g)
-    ar = np.array([l[i].split('_') for i in range(len(l))]).astype(int)
-    shape = (np.max(ar[:,0])+1,np.max(ar[:,1])+1)
-    coord_names = list(g['0_0'])
-    N = len(coord_names)
-    coord_types = [type(np.array(g['0_0/'+coord_names[i]+'/data'])[0]) for i in range(N)]
-    coordinates = [(coord_names[i],coord_types[i]) for i in range(N)]
+    dset = g['data']
+    shape = dset.shape
+    coordinates = h5py.check_vlen_dtype(dset.dtype)
     pla = PointListArray(dtype=coordinates,shape=shape,name=name)
-    for (i,j) in tqdmnd(range(shape[0]),range(shape[1]),desc="Reading PointListArray",unit="PointList"):
-        g_pl = g[str(i)+'_'+str(j)]
-        L = len(np.array(g_pl[coordinates[0][0]+'/data']))
-        data = np.zeros(L,dtype=coordinates)
-        for i in range(N):
-            coord = coordinates[i][0]
-            data[coord] = np.array(g_pl[coord+'/data'])
-        pla.get_pointlist(i,j).data = data
+    for (i,j) in tqdmnd(shape[0],shape[1],desc="Reading PointListArray",unit="PointList"):
+        try:
+            pla.get_pointlist(i,j).data = dset[i,j]
+        except ValueError:
+            pass
     return pla
-
-
-
-
