@@ -1,11 +1,16 @@
-from . import utils
-from . import fit
-from . import preprocess
-from . import diskdetection
-from . import calibration
-from . import latticevectors
-from . import classification
-from . import dpc
-from . import rdf
+from . import virtualdiffraction
 from . import virtualimage
+from . import probe
+from . import diskdetection
+from . import dpc
+from . import calibration
+from . import utils
+from . import classification
+
+#from . import fit
+#from . import calibration
+from . import latticevectors
+#from . import classification
+#from . import rdf
+#from . import virtualimage
 from . import diffraction
