@@ -10,7 +10,7 @@ import numpy as np
 from typing import Union, Optional
 
 from ...io.datastructure import PointList, PointListArray
-from ..utils import tqdmnd
+from ...utils.tqdmnd import tqdmnd
 
 
 def plot_structure(
@@ -642,12 +642,20 @@ def plot_orientation_plan(
     #     #     self.orientation_ref_perp[index_plot, :, :])) / self.orientation_ref_max
     # else:
     # im_plot = self.orientation_ref[index_plot, :, :] / self.orientation_ref_max
-    im_plot = (
-        np.real(np.fft.ifft(self.orientation_ref[index_plot, :, :], axis=1)).astype(
-            "float"
+    if self.CUDA:
+        im_plot = (
+            np.real(np.fft.ifft(self.orientation_ref[index_plot, :, :].get(), axis=1)).astype(
+                "float"
+            )
+            / self.orientation_ref_max
+        )
+    else:
+        im_plot = (
+            np.real(np.fft.ifft(self.orientation_ref[index_plot, :, :], axis=1)).astype(
+                "float"
+            )
+            / self.orientation_ref_max
         )
-        / self.orientation_ref_max
-    )
 
     # coordinates
     x = self.orientation_gamma * 180 / np.pi
@@ -713,6 +721,7 @@ def plot_diffraction_pattern(
     shift_labels: float = 0.08,
     shift_marker: float = 0.005,
     min_marker_size: float = 1e-6,
+    max_marker_size: float = 1000,
     figsize: Union[list, tuple, np.ndarray] = (12, 6),
     returnfig: bool = False,
     input_fig_handle=None,
@@ -729,8 +738,10 @@ def plot_diffraction_pattern(
         plot_range_kx_ky (float):       2 element numpy vector giving the plot range
         add_labels (bool):              flag to add hkl labels to peaks
         min_marker_size (float):        minimum marker size for the comparison peaks
+        max_marker_size (float):        maximum marker size for the comparison peaks
         figsize (2 element float):      size scaling of figure axes
         returnfig (bool):               set to True to return figure and axes handles
+        input_fig_handle (fig,ax)       Tuple containing a figure / axes handle for the plot.
     """
 
     # 2D plotting
@@ -759,15 +770,17 @@ def plot_diffraction_pattern(
             scale_markers_compare = scale_markers
 
         if power_markers == 2:
-            marker_size_compare = np.maximum(
+            marker_size_compare = np.clip(
                 scale_markers_compare * bragg_peaks_compare.data["intensity"],
                 min_marker_size,
+                max_marker_size,
             )
         else:
-            marker_size_compare = np.maximum(
+            marker_size_compare = np.clip(
                 scale_markers_compare
                 * (bragg_peaks_compare.data["intensity"] ** (power_markers / 2)),
                 min_marker_size,
+                max_marker_size,
             )
 
         ax.scatter(
@@ -785,6 +798,9 @@ def plot_diffraction_pattern(
             facecolor="k",
         )
 
+    ax.set_xlabel("$q_y$ [Å$^{-1}$]")
+    ax.set_ylabel("$q_x$ [Å$^{-1}$]")
+
     if plot_range_kx_ky is not None:
         ax.set_xlim((-plot_range_kx_ky[0], plot_range_kx_ky[0]))
         ax.set_ylim((-plot_range_kx_ky[1], plot_range_kx_ky[1]))
@@ -840,13 +856,14 @@ def plot_diffraction_pattern(
 def plot_orientation_maps(
     self,
     orientation_map,
-    orientation_ind: int = None,
+    orientation_ind: int = 0,
     dir_in_plane_degrees: float = 0.0,
     corr_range: np.ndarray = np.array([0, 5]),
     corr_normalize: bool = True,
     scale_legend: bool = None,
     figsize: Union[list, tuple, np.ndarray] = (16, 5),
     figbound: Union[list, tuple, np.ndarray] = (0.01, 0.005),
+    show_axes: bool = True,
     camera_dist = None,
     plot_limit = None,
     swap_axes_xy_limits = False,
@@ -865,6 +882,7 @@ def plot_orientation_maps(
         scale_legend (float):               2 elements, x and y scaling of legend panel
         figsize (array):                    2 elements defining figure size
         figbound (array):                   2 elements defining figure boundary
+        show_axes (bool):                   Flag setting whether orienation map axes are visible.
         camera_dist (float):                distance of camera from legend
         plot_limit (array):                 2x3 array defining plot boundaries of egend
         swap_axes_xy_limits (bool):         swap x and y boundaries for legend (not sure why we need this in some cases)
@@ -885,9 +903,6 @@ def plot_orientation_maps(
     # Legend size
     leg_size = np.array([300, 300], dtype="int")
 
-    if orientation_ind is None:
-        orientation_ind = 0
-
     # Color of the 3 corners
     color_basis = np.array(
         [
@@ -929,16 +944,13 @@ def plot_orientation_maps(
     ct = np.cos(dir_in_plane)
     st = np.sin(dir_in_plane)
     basis_x = np.zeros((orientation_map.num_x,orientation_map.num_y,3))
+    basis_y = np.zeros((orientation_map.num_x,orientation_map.num_y,3))
     basis_z = np.zeros((orientation_map.num_x,orientation_map.num_y,3))
     rgb_x = np.zeros((orientation_map.num_x,orientation_map.num_y,3))
     rgb_z = np.zeros((orientation_map.num_x,orientation_map.num_y,3))
 
     # Basis for fitting orientation projections 
     A = np.linalg.inv(self.orientation_zone_axis_range).T
-    # A = self.orientation_zone_axis_range
-    # print(np.round(A,decimals=3))
-    # A = np.linalg.inv(self.orientation_zone_axis_range).T
-    # A = self.orientation_zone_axis_range
 
     # Correlation masking
     corr = orientation_map.corr[:,:,orientation_ind]
@@ -958,6 +970,9 @@ def plot_orientation_maps(
 
         if self.pymatgen_available:
             basis_x[rx,ry,:] = A @ orientation_map.family[rx,ry,orientation_ind,:,0]
+            basis_y[rx,ry,:] = A @ orientation_map.family[rx,ry,orientation_ind,:,1]
+            basis_x[rx,ry,:] = basis_x[rx,ry,:]*ct + basis_y[rx,ry,:]*st
+
             basis_z[rx,ry,:] = A @ orientation_map.family[rx,ry,orientation_ind,:,2]
         else:
             basis_z[rx,ry,:] = A @ orientation_map.matrix[rx,ry,orientation_ind,:,2]
@@ -965,11 +980,22 @@ def plot_orientation_maps(
     basis_z = np.clip(basis_z,0,1)
 
     # Convert to RGB images
-    basis_x_scale = mask[:,:,None] * basis_x / np.max(basis_x,axis=2)[:,:,None]
+    basis_x_max = np.max(basis_x,axis=2)
+    sub = basis_x_max > 0
+    basis_x_scale = basis_x * mask[:,:,None] 
+    for a0 in range(3):
+        basis_x_scale[:,:,a0][sub] /= basis_x_max[sub]
+        basis_x_scale[:,:,a0][np.logical_not(sub)] = 0
     rgb_x = basis_x_scale[:,:,0][:,:,None]*color_basis[0,:][None,None,:] \
         + basis_x_scale[:,:,1][:,:,None]*color_basis[1,:][None,None,:] \
         + basis_x_scale[:,:,2][:,:,None]*color_basis[2,:][None,None,:]
-    basis_z_scale = mask[:,:,None] * basis_z / np.max(basis_z,axis=2)[:,:,None]
+
+    basis_z_max = np.max(basis_z,axis=2)
+    sub = basis_z_max > 0
+    basis_z_scale = basis_z * mask[:,:,None]
+    for a0 in range(3):
+        basis_z_scale[:,:,a0][sub] /= basis_z_max[sub]
+        basis_z_scale[:,:,a0][np.logical_not(sub)] = 0
     rgb_z = basis_z_scale[:,:,0][:,:,None]*color_basis[0,:][None,None,:] \
         + basis_z_scale[:,:,1][:,:,None]*color_basis[1,:][None,None,:] \
         + basis_z_scale[:,:,2][:,:,None]*color_basis[2,:][None,None,:]
@@ -1083,6 +1109,14 @@ def plot_orientation_maps(
             horizontalalignment='center')
     ax_z.imshow(rgb_z)
 
+    # Labels for orientation images
+    ax_x.set_title("In-Plane Orientation", size=20)
+    ax_z.set_title("Out-of-Plane Orientation", size=20)
+    if show_axes is False:
+        ax_x.axis("off")
+        ax_z.axis("off")
+
+
     # Triangulate faces
     p = self.orientation_vecs[:,(1,0,2)]
     tri = mtri.Triangulation(
@@ -1236,433 +1270,13 @@ def plot_orientation_maps(
 
     plt.show()
 
-
-
-    # collection = art3d.PolyCollection(self.orientation_vecs)
-    # ax_l.add_collection(collection)
-
-    # print(tri.)
-    # print(type(tri))
-    # ax_l.plot_trisurf(
-    #     self.orientation_vecs[:,1],
-    #     self.orientation_vecs[:,0],
-    #     self.orientation_vecs[:,2],
-    #     triangles=tri.triangles, 
-    #     color=rgb_legend)
-    # maskedTris = tri.get_masked_triangles()
-    # verts = np.stack((tri.x[maskedTris], tri.y[maskedTris]), axis=-1)
-    # collection = art3d.PolyCollection(verts)
-    # # collection.set_vertexcolor(rgb_legend)
-    # ax_l.add_collection(collection)
-    # shading='gouraud'
-    # pc = art3d.Poly3DCollection(
-    #     self.orientation_vecs,
-    #     alpha=1,
-    # )
-    # ax_l.add_collection(pc)
-
-
-    # art3d.Poly3DCollection
-
-    # plt.gca().autoscale_view()
-    # ax_l.plot_surface(
-    #     self.orientation_vecs[:,1], 
-    #     self.orientation_vecs[:,0], 
-    #     self.orientation_vecs[:,2], 
-    #     )
-
-
-
-    # # Generate crystal basis images.
-    # # Each channel represents one vector of self.orientation_zone_axis_range.
-    # # for ax in range(1):
-    # #     for ay in range(1):
-    # count_max = 1
-    # for rx, ry in tqdmnd(
-    #     orientation_map.num_x,
-    #     10,#orientation_map.num_y,
-    #     desc="Generating orientation maps",
-    #     unit=" PointList",
-    #     disable=not progress_bar,
-    #     ):
-    #     if orientation_map.corr[rx,ry] > 0:
-
-    #         # Reflect the in-plane direction into orientation triangle
-    #         v = orientation_map.matrix[rx,ry,orientation_ind,:,0] * ct \
-    #             + orientation_map.matrix[rx,ry,orientation_ind,:,1] * st
-    #         w = np.linalg.solve(A, v)
-    #         if np.min(w) < 0:        
-    #             count = 0
-    #             while count < count_max:
-    #                 if np.min(w) < 0:
-    #                     v0 = v @ A_ref[0]
-    #                     v1 = v @ A_ref[1]
-    #                     v2 = v @ A_ref[2]
-    #                     w0 = np.linalg.solve(A, v0)
-    #                     w1 = np.linalg.solve(A, v1)
-    #                     w2 = np.linalg.solve(A, v2)
-    #                     ind = np.argmax([
-    #                         np.mean(w0),
-    #                         np.mean(w1),
-    #                         np.mean(w2)])
-    #                     if ind == 0:
-    #                         v = v0
-    #                         w = w0
-    #                     elif ind == 1:
-    #                         v = v1
-    #                         w = w1
-    #                     else:
-    #                         v = v2
-    #                         w = w2
-    #                     # for a0 in range(A_ref.shape[0])
-    #                     #     v_test = v @ A_ref[a0]
-    #                     #     w_test = p.linalg.solve(A, v_test)
-    #                     #     if a0 == 0:
-    #                     #         v = v_test
-    #                     #         w = w_test
-    #                     #     else:
-    #                     #         if np.mean(w_test) > np.mean(w):
-    #                     #             v = v_test
-    #                     #             w = w_test
-    #                 else:
-    #                     count = count_max
-    #         dir_x[rx,ry] = w
-
-    #         # Reflect the out-of-plane direction into orientation triangle
-    #         v = orientation_map.matrix[rx,ry,orientation_ind,:,2]
-    #         w = np.linalg.solve(A, v)
-    #         if np.min(w) < 0:        
-    #             count = 0
-    #             while count < count_max:
-    #                 if np.min(w) < 0:
-    #                     v0 = v @ A_ref[0]
-    #                     v1 = v @ A_ref[1]
-    #                     v2 = v @ A_ref[2]
-    #                     w0 = np.linalg.solve(A, v0)
-    #                     w1 = np.linalg.solve(A, v1)
-    #                     w2 = np.linalg.solve(A, v2)
-    #                     ind = np.argmax([
-    #                         np.mean(w0),
-    #                         np.mean(w1),
-    #                         np.mean(w2)])
-    #                     if ind == 0:
-    #                         v = v0
-    #                         w = w0
-    #                     elif ind == 1:
-    #                         v = v1
-    #                         w = w1
-    #                     else:
-    #                         v = v2
-    #                         w = w2
-    #                 else:
-    #                     count = count_max
-    #         dir_z[rx,ry] = w
-
-
-    # # Basis for fitting fiber texture
-    # if self.orientation_fiber:
-    #     p1_proj = (
-    #         np.dot(
-    #             self.orientation_zone_axis_range[1, :],
-    #             self.orientation_zone_axis_range[0, :],
-    #         )
-    #         * self.orientation_zone_axis_range[0, :]
-    #     )
-    #     p2_proj = (
-    #         np.dot(
-    #             self.orientation_zone_axis_range[2, :],
-    #             self.orientation_zone_axis_range[0, :],
-    #         )
-    #         * self.orientation_zone_axis_range[0, :]
-    #     )
-    #     p1_sub = self.orientation_zone_axis_range[1, :] - p1_proj
-    #     p2_sub = self.orientation_zone_axis_range[2, :] - p2_proj
-    #     B = np.vstack((self.orientation_zone_axis_range[0, :], p1_sub, p2_sub)).T
-
-    # # initalize image arrays
-    # images_orientation = np.zeros(
-    #     (orientation_matrices.shape[0], orientation_matrices.shape[1], 3, 3)
-    # )
-
-    # # in-plane rotation array if needed
-    # if orientation_rotate_xy is not None:
-    #     m = np.array(
-    #         [
-    #             [np.cos(orientation_rotate_xy), -np.sin(orientation_rotate_xy), 0],
-    #             [np.sin(orientation_rotate_xy), np.cos(orientation_rotate_xy), 0],
-    #             [0, 0, 1],
-    #         ]
-    #     )
-
-    # # loop over all pixels and calculate weights
-    # for ax in range(orientation_matrices.shape[0]):
-    #     for ay in range(orientation_matrices.shape[1]):
-    #         if orientation_matrices.ndim == 4:
-    #             orient = orientation_matrices[ax, ay, :, :]
-    #         else:
-    #             orient = orientation_matrices[ax, ay, :, :, orientation_index_plot]
-
-    #         # Rotate in-plane if needed
-    #         if orientation_rotate_xy is not None:
-    #             orient = m @ orient
-
-    #         if self.orientation_fiber:
-    #             # in-plane rotation
-    #             # w = np.linalg.solve(A, orient[:, 0])
-    #             w = np.linalg.solve(B, orient[:, 0])
-
-    #             h = np.mod(
-    #                 np.arctan2(w[2], w[1])
-    #                 * 180
-    #                 / np.pi
-    #                 / self.orientation_fiber_angles[1],
-    #                 1,
-    #             )
-    #             w0 = np.maximum(1 - 3 * np.abs(np.mod(3 / 6 - h, 1) - 1 / 2), 0)
-    #             w1 = np.maximum(1 - 3 * np.abs(np.mod(5 / 6 - h, 1) - 1 / 2), 0)
-    #             w2 = np.maximum(1 - 3 * np.abs(np.mod(7 / 6 - h, 1) - 1 / 2), 0)
-    #             w_scale = 1 / (1 - np.exp(-np.max((w0, w1, w2))))
-
-    #             rgb = (
-    #                 color_basis[0, :] * w0 * w_scale
-    #                 + color_basis[1, :] * w1 * w_scale
-    #                 + color_basis[2, :] * w2 * w_scale
-    #             )
-    #             images_orientation[ax, ay, :, 0] = rgb
-
-    #             # zone axis
-    #             w = np.linalg.solve(A, orient[:, 2])
-    #             w = w / (1 - np.exp(-np.max(w)))
-    #             rgb = (
-    #                 color_basis[0, :] * w[0]
-    #                 + color_basis[1, :] * w[1]
-    #                 + color_basis[2, :] * w[2]
-    #             )
-    #             images_orientation[ax, ay, :, 2] = rgb
-
-    #         else:
-    #             for a0 in range(3):
-    #                 # Cubic sorting for now - needs to be updated with symmetries
-    #                 # w = np.linalg.solve(A,orient[:,a0])
-    #                 w = np.linalg.solve(A, np.sort(np.abs(orient[:, a0])))
-    #                 # w = np.linalg.solve(A, orient[:, a0])
-    #                 w = w / (1 - np.exp(-np.max(w)))
-
-    #                 rgb = (
-    #                     color_basis[0, :] * w[0]
-    #                     + color_basis[1, :] * w[1]
-    #                     + color_basis[2, :] * w[2]
-    #                 )
-    #                 images_orientation[ax, ay, :, a0] = rgb
-
-    # # clip range
-    # images_orientation = np.clip(images_orientation, 0, 1)
-
-    # # Masking
-    # if corr_all is not None:
-    #     if orientation_matrices.ndim == 4:
-    #         if corr_normalize:
-    #             mask = corr_all / np.mean(corr_all)
-    #         else:
-    #             mask = corr_all
-    #     else:
-    #         if corr_normalize:
-    #             mask = corr_all[:, :, orientation_index_plot] / np.mean(
-    #                 corr_all[:, :, orientation_index_plot]
-    #             )
-    #         else:
-    #             mask = corr_all[:, :, orientation_index_plot]
-
-    #     mask = (mask - corr_range[0]) / (corr_range[1] - corr_range[0])
-    #     mask = np.clip(mask, 0, 1)
-
-    #     for a0 in range(3):
-    #         for a1 in range(3):
-    #             images_orientation[:, :, a0, a1] *= mask
-
-    # # Draw legend for zone axis
-    # x = np.linspace(0, 1, leg_size[0])
-    # y = np.linspace(0, 1, leg_size[1])
-    # ya, xa = np.meshgrid(y, x)
-    # mask_legend = np.logical_and(2 * xa > ya, 2 * xa < 2 - ya)
-    # w0 = 1 - xa - 0.5 * ya
-    # w1 = xa - 0.5 * ya
-    # w2 = ya
-
-    # w_scale = np.maximum(np.maximum(w0, w1), w2)
-    # # w_scale = w0 + w1 + w2
-    # # w_scale = (w0**4 + w1**4 + w2**4)**0.25
-    # w_scale = 1 - np.exp(-w_scale)
-    # w0 = w0 / w_scale  # * mask_legend
-    # w1 = w1 / w_scale  # * mask_legend
-    # w2 = w2 / w_scale  # * mask_legend
-
-    # im_legend = np.zeros((leg_size[0], leg_size[1], 3))
-    # for a0 in range(3):
-    #     im_legend[:, :, a0] = (
-    #         w0 * color_basis[0, a0] + w1 * color_basis[1, a0] + w2 * color_basis[2, a0]
-    #     )
-    #     im_legend[:, :, a0] *= mask_legend
-    #     im_legend[:, :, a0] += 1 - mask_legend
-    # im_legend = np.clip(im_legend, 0, 1)
-
-    # if self.orientation_fiber:
-    #     # Draw legend for in-plane rotation
-    #     x = np.linspace(-1, 1, leg_size[0])
-    #     y = np.linspace(-1, 1, leg_size[1])
-    #     ya, xa = np.meshgrid(y, x)
-    #     mask_legend = xa ** 2 + ya ** 2 <= 1
-
-    #     h = np.mod(
-    #         np.arctan2(ya, xa) * 180 / np.pi / self.orientation_fiber_angles[1], 1
-    #     )
-    #     w0 = np.maximum(1 - 3 * np.abs(np.mod(3 / 6 - h, 1) - 1 / 2), 0)
-    #     w1 = np.maximum(1 - 3 * np.abs(np.mod(5 / 6 - h, 1) - 1 / 2), 0)
-    #     w2 = np.maximum(1 - 3 * np.abs(np.mod(7 / 6 - h, 1) - 1 / 2), 0)
-
-    #     w_scale = np.maximum(np.maximum(w0, w1), w2)
-    #     # w_scale = w0 + w1 + w2
-    #     # w_scale = (w0**4 + w1**4 + w2**4)**0.25
-    #     w_scale = 1 - np.exp(-w_scale)
-    #     w0 = w0 / w_scale  # * mask_legend
-    #     w1 = w1 / w_scale  # * mask_legend
-    #     w2 = w2 / w_scale  # * mask_legend
-
-    #     inplane_legend = np.zeros((leg_size[0], leg_size[1], 3))
-    #     for a0 in range(3):
-    #         inplane_legend[:, :, a0] = (
-    #             w0 * color_basis[0, a0]
-    #             + w1 * color_basis[1, a0]
-    #             + w2 * color_basis[2, a0]
-    #         )
-    #         inplane_legend[:, :, a0] *= mask_legend
-    #         inplane_legend[:, :, a0] += 1 - mask_legend
-    #     inplane_legend = np.clip(inplane_legend, 0, 1)
-
-    # # plotting
-    # if figlayout[0] == 1 and figlayout[1] == 4:
-    #     fig, ax = plt.subplots(1, 4, figsize=figsize)
-    # elif figlayout[0] == 2 and figlayout[1] == 2:
-    #     fig, ax = plt.subplots(2, 2, figsize=figsize)
-    #     ax = np.array(
-    #         [
-    #             ax[0, 0],
-    #             ax[0, 1],
-    #             ax[1, 0],
-    #             ax[1, 1],
-    #         ]
-    #     )
-    # elif figlayout[0] == 4 and figlayout[1] == 1:
-    #     fig, ax = plt.subplots(4, 1, figsize=figsize)
-
-    # ax[0].imshow(images_orientation[:, :, :, 0])
-    # if self.orientation_fiber:
-    #     ax[1].imshow(inplane_legend, aspect="auto")
-    # else:
-    #     ax[1].imshow(images_orientation[:, :, :, 1])
-    # ax[2].imshow(images_orientation[:, :, :, 2])
-
-    # if self.orientation_fiber:
-    #     ax[0].set_title("In-Plane Rotation", size=20)
-    #     # ax[1].imshow(im_legend, aspect="auto")
-
-    # else:
-    #     ax[0].set_title("Orientation of x-axis", size=20)
-    #     ax[1].set_title("Orientation of y-axis", size=20)
-    # ax[2].set_title("Zone Axis", size=20)
-    # ax[0].xaxis.tick_top()
-    # ax[1].xaxis.tick_top()
-    # ax[2].xaxis.tick_top()
-
-    # # Legend
-    # ax[3].imshow(im_legend, aspect="auto")
-
-    # label_0 = self.orientation_zone_axis_range[0, :]
-    # label_0 = np.round(label_0 * 1e3) * 1e-3
-    # label_0 = label_0 / np.min(np.abs(label_0[np.abs(label_0) > 0]))
-
-    # label_1 = self.orientation_zone_axis_range[1, :]
-    # label_1 = np.round(label_1 * 1e3) * 1e-3
-    # label_1 = label_1 / np.min(np.abs(label_1[np.abs(label_1) > 0]))
-
-    # label_2 = self.orientation_zone_axis_range[2, :]
-    # label_2 = np.round(label_2 * 1e3) * 1e-3
-    # label_2 = label_2 / np.min(np.abs(label_2[np.abs(label_2) > 0]))
-
-    # ax[3].yaxis.tick_right()
-    # ax[3].set_yticks([(leg_size[0] - 1) / 2])
-    # ax[3].set_yticklabels([str(label_2)])
-
-    # ax3a = ax[3].twiny()
-    # ax3b = ax[3].twiny()
-
-    # ax3a.set_xticks([0])
-    # ax3a.set_xticklabels([str(label_0)])
-    # ax3a.xaxis.tick_top()
-    # ax3b.set_xticks([0])
-    # ax3b.set_xticklabels([str(label_1)])
-    # ax3b.xaxis.tick_bottom()
-    # ax[3].set_xticks([])
-
-    # # ax[3].xaxis.label.set_color('none')
-    # ax[3].spines["left"].set_color("none")
-    # ax[3].spines["right"].set_color("none")
-    # ax[3].spines["top"].set_color("none")
-    # ax[3].spines["bottom"].set_color("none")
-
-    # ax3a.spines["left"].set_color("none")
-    # ax3a.spines["right"].set_color("none")
-    # ax3a.spines["top"].set_color("none")
-    # ax3a.spines["bottom"].set_color("none")
-
-    # ax3b.spines["left"].set_color("none")
-    # ax3b.spines["right"].set_color("none")
-    # ax3b.spines["top"].set_color("none")
-    # ax3b.spines["bottom"].set_color("none")
-
-    # ax[3].tick_params(labelsize=16)
-    # ax3a.tick_params(labelsize=16)
-    # ax3b.tick_params(labelsize=16)
-
-    # if self.orientation_fiber:
-    #     ax[1].axis("off")
-
-    # if scale_legend is not None:
-    #     pos = ax[3].get_position()
-    #     pos_new = [
-    #         pos.x0,
-    #         pos.y0 + pos.height * (1 - scale_legend[1]) / 2,
-    #         pos.width * scale_legend[0],
-    #         pos.height * scale_legend[1],
-    #     ]
-    #     ax[3].set_position(pos_new)
-
-    #     if self.orientation_fiber:
-    #         pos = ax[1].get_position()
-    #         if np.size(scale_legend) == 2:
-    #             pos_new = [
-    #                 pos.x0,
-    #                 pos.y0 + pos.height * (1 - scale_legend[1]) / 2,
-    #                 pos.width * scale_legend[0],
-    #                 pos.height * scale_legend[1],
-    #             ]
-    #         elif np.size(scale_legend) == 4:
-    #             pos_new = [
-    #                 pos.x0,
-    #                 pos.y0 + pos.height * (1 - scale_legend[3]) / 2,
-    #                 pos.width * scale_legend[2],
-    #                 pos.height * scale_legend[3],
-    #             ]
-    #         ax[1].set_position(pos_new)
-
-
     images_orientation = np.zeros((
         orientation_map.num_x,
         orientation_map.num_y,
         3,2))
     if self.pymatgen_available:
         images_orientation[:,:,:,0] = rgb_x
-    images_orientation[:,:,:,0] = rgb_z
+    images_orientation[:,:,:,1] = rgb_z
 
     if returnfig:
         ax = [ax_x,ax_z,ax_l]
@@ -1671,38 +1285,17 @@ def plot_orientation_maps(
         return images_orientation
 
 
-# def crystal_to_cartesian(self, zone_axis):
-#     vec_cart = zone_axis @ self.lat_real
-#     return vec_cart / np.linalg.norm(vec_cart)
-
-# def cartesian_to_crystal(self, vec_cart):
-#     zone_axis = vec_cart @ np.linalg.inv(self.lat_real)
-#     return zone_axis / np.linalg.norm(zone_axis)
-
-
-# def cartesian_to_crystal(self, zone_axis):
-#     vec_cart = zone_axis @ self.lat_real
-#     return vec_cart / np.linalg.norm(vec_cart)
-
-
-# def crystal_to_cartesian(self, vec_cart):
-#     zone_axis = vec_cart @ np.linalg.inv(self.lat_real)
-#     return zone_axis / np.linalg.norm(zone_axis)
-
-
-
-
-
 
 def plot_fiber_orientation_maps(
     self,
     orientation_map,
-    orientation_ind: int = None,
+    orientation_ind: int = 0,
     symmetry_order: int = None,
     symmetry_mirror: bool = False,
     dir_in_plane_degrees: float = 0.0,
-    corr_range: np.ndarray = np.array([0, 5]),
+    corr_range: np.ndarray = np.array([0, 2]),
     corr_normalize: bool = True,
+    show_axes: bool = True,
     medfilt_size: int = None,
     cmap_out_of_plane: 'string' = 'plasma',
     leg_size: int = 200,
@@ -1719,6 +1312,7 @@ def plot_fiber_orientation_maps(
         dir_in_plane_degrees (float):       Reference in-plane angle (degrees).  Default is 0 / x-axis / vertical down.
         corr_range (np.ndarray):            Correlation intensity range for the plot
         corr_normalize (bool):              If true, set mean correlation to 1.
+        show_axes (bool):                   Flag setting whether orienation map axes are visible.
         figsize (array):                    2 elements defining figure size
         figbound (array):                   2 elements defining figure boundary
         returnfig (bool):                   set to True to return figure and axes handles
@@ -1752,6 +1346,7 @@ def plot_fiber_orientation_maps(
     mask = (corr - corr_range[0]) / (corr_range[1] - corr_range[0])
     mask = np.clip(mask, 0, 1)
 
+
     # Get symmetry
     if symmetry_order is None:
         symmetry_order = np.round(360.0 / self.orientation_fiber_angles[1])
@@ -1760,7 +1355,10 @@ def plot_fiber_orientation_maps(
 
     # Generate out-of-plane orientation signal
     ang_op = orientation_map.angles[:,:,orientation_ind,1]
-    sig_op = ang_op / np.deg2rad(self.orientation_fiber_angles[0])
+    if self.orientation_fiber_angles[0] > 0:
+        sig_op = ang_op / np.deg2rad(self.orientation_fiber_angles[0])
+    else:
+        sig_op = ang_op
     if medfilt_size is not None:
         sig_op = medfilt(sig_op,medfilt_size)
 
@@ -1771,6 +1369,7 @@ def plot_fiber_orientation_maps(
     if symmetry_mirror:
         sub = np.sin((symmetry_order/2)*ang_ip) < 0
         sig_ip[sub] = np.mod(-sig_ip[sub],1)
+    sig_ip = np.mod(sig_ip - (dir_in_plane_degrees/360.*symmetry_order),1.)
     if medfilt_size is not None:
         sig_ip = medfilt(sig_ip,medfilt_size)
 
@@ -1837,37 +1436,47 @@ def plot_fiber_orientation_maps(
     ax_ip.imshow(im_ip)
     ax_ip.set_title("In-Plane Rotation", size=16)
 
-    #out of plane
-    ax_op.imshow(im_op)
-    ax_op.set_title("Out-of-Plane Tilt", size=16)
+    # out of plane
+    if self.orientation_fiber_angles[0] > 0:
+        ax_op.imshow(im_op)
+        ax_op.set_title("Out-of-Plane Tilt", size=16)
+    else:
+        ax_op.axis('off')
+
+    if show_axes is False:
+        ax_ip.axis("off")
+        ax_op.axis("off")
 
     # in plane legend
     ax_ip_l.imshow(im_ip_leg)
     ax_ip_l.set_axis_off()
 
     # out of plane legend
-    t = np.tile(np.linspace(0,1,leg_size,endpoint=True),(np.round(leg_size/10).astype('int'),1))
-    im_op_leg = cmap(t)
-    im_op_leg = np.delete(im_op_leg, 3, axis=2)
-    ax_op_l.imshow(im_op_leg)
-    ax_op_l.set_yticks([])
+    if self.orientation_fiber_angles[0] > 0:
+        t = np.tile(np.linspace(0,1,leg_size,endpoint=True),(np.round(leg_size/10).astype('int'),1))
+        im_op_leg = cmap(t)
+        im_op_leg = np.delete(im_op_leg, 3, axis=2)
+        ax_op_l.imshow(im_op_leg)
+        ax_op_l.set_yticks([])
 
-    ticks = [
-        np.round(leg_size*0.0), 
-        np.round(leg_size*0.25), 
-        np.round(leg_size*0.5), 
-        np.round(leg_size*0.75), 
-        np.round(leg_size*1.0), 
-        ]
-    labels = [
-        str(np.round(self.orientation_fiber_angles[0]*0.00)) + '$\degree$', 
-        str(np.round(self.orientation_fiber_angles[0]*0.25)) + '$\degree$', 
-        str(np.round(self.orientation_fiber_angles[0]*0.50)) + '$\degree$', 
-        str(np.round(self.orientation_fiber_angles[0]*0.75)) + '$\degree$', 
-        str(np.round(self.orientation_fiber_angles[0]*1.00)) + '$\degree$', 
-        ]
-    ax_op_l.set_xticks(ticks)
-    ax_op_l.set_xticklabels(labels)
+        ticks = [
+            np.round(leg_size*0.0), 
+            np.round(leg_size*0.25), 
+            np.round(leg_size*0.5), 
+            np.round(leg_size*0.75), 
+            np.round(leg_size*1.0), 
+            ]
+        labels = [
+            str(np.round(self.orientation_fiber_angles[0]*0.00)) + '$\degree$', 
+            str(np.round(self.orientation_fiber_angles[0]*0.25)) + '$\degree$', 
+            str(np.round(self.orientation_fiber_angles[0]*0.50)) + '$\degree$', 
+            str(np.round(self.orientation_fiber_angles[0]*0.75)) + '$\degree$', 
+            str(np.round(self.orientation_fiber_angles[0]*1.00)) + '$\degree$', 
+            ]
+        ax_op_l.set_xticks(ticks)
+        ax_op_l.set_xticklabels(labels)
+    else:
+        ax_op_l.axis('off')
 
     images_orientation = np.zeros((
         orientation_map.num_x,
@@ -2040,4 +1649,4 @@ jmol_colors = {
 
 # def isPointWithinPolygon(point, polygonVertexCoords):
 #      path = matplotlib.path.Path( polygonVertexCoords )
-#      return path.contains_point(point[0], point[1]) 
\ No newline at end of file
+#      return path.contains_point(point[0], point[1]) 
